@@ -8,10 +8,13 @@ fi
 
 declare -A PKG_MAP
 
+SCRIPT_HOME="$(cd "$(dirname "$0")" && pwd)"
+export BIFROST_HOME=$SCRIPT_HOME/..
+
 # NOTE(rpittau): we need a stable recent version of pip to avoid issues with
 # the cryptography package.
-PIP_MIN_REQ="20.0.1"
-PIP_TUPLE="(20, 0, 1)"
+PIP_MIN_REQ="22.3.1"
+PIP_TUPLE="(22, 3, 1)"
 
 # workaround: for latest bindep to work, it needs to use en_US local
 export LANG=en_US.UTF-8
@@ -19,7 +22,7 @@ export LANG=en_US.UTF-8
 export VENV=${VENV:-/opt/stack/bifrost}
 
 # NOTE(dtantsur): change this when creating a stable branch
-BRANCH=${ZUUL_BRANCH:-2023.2}
+BRANCH=${ZUUL_BRANCH:-master}
 CONSTRAINTS_FILE=${UPPER_CONSTRAINTS_FILE:-${TOX_CONSTRAINTS_FILE:-https://releases.openstack.org/constraints/upper/$BRANCH}}
 
 CHECK_CMD_PKGS=(
@@ -69,6 +72,12 @@ case ${ID,,} in
     # NOTE(rpittau): epel repos are installed but the content is purged
     # in  the CI images, we remove them and reinstall later
     sudo -E ${PKG_MANAGER} remove -y epel-release epel-next-release
+
+    if [[ $NAME == 'CentOS Stream' ]] && [[ $VERSION == 9 ]]; then
+        export CONSTRAINTS_FILE="$BIFROST_HOME/upper-constraints-cs9-py39.txt"
+        export UPPER_CONSTRAINTS_FILE=$CONSTRAINTS_FILE
+        export TOX_CONSTRAINTS_FILE=$CONSTRAINTS_FILE
+    fi
     ;;
 
     *) echo "ERROR: Supported package manager not found.  Supported: apt, dnf, yum, zypper"; exit 1;;
